@@ -1,5 +1,5 @@
 /* pr -- convert text files for printing.
-   Copyright (C) 1988, 1991, 1995-2010 Free Software Foundation, Inc.
+   Copyright (C) 1988, 1991, 1995-2011 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -314,6 +314,7 @@
 #include <sys/types.h>
 #include "system.h"
 #include "error.h"
+#include "fadvise.h"
 #include "hard-locale.h"
 #include "mbswidth.h"
 #include "quote.h"
@@ -876,7 +877,7 @@ main (int argc, char **argv)
                 ? xmalloc ((argc - 1) * sizeof (char *))
                 : NULL);
 
-  for (;;)
+  while (true)
     {
       int oi = -1;
       int c = getopt_long (argc, argv, short_options, long_options, &oi);
@@ -1507,6 +1508,7 @@ open_file (char *name, COLUMN *p)
         error (0, errno, "%s", name);
       return false;
     }
+  fadvise (p->fp, FADVISE_SEQUENTIAL);
   p->status = OPEN;
   p->full_page_printed = false;
   ++total_files;
@@ -1915,10 +1917,10 @@ init_store_cols (void)
 
   free (line_vector);
   /* FIXME: here's where it was allocated.  */
-  line_vector = xmalloc ((total_lines + 1) * sizeof (int *));
+  line_vector = xmalloc ((total_lines + 1) * sizeof *line_vector);
 
   free (end_vector);
-  end_vector = xmalloc (total_lines * sizeof (int *));
+  end_vector = xmalloc (total_lines * sizeof *end_vector);
 
   free (buff);
   buff_allocated = (use_col_separator
@@ -2437,7 +2439,7 @@ static bool
 read_line (COLUMN *p)
 {
   int c;
-  int chars IF_LINT (= 0);
+  int chars IF_LINT ( = 0);
   int last_input_position;
   int j, k;
   COLUMN *q;
@@ -2526,7 +2528,7 @@ read_line (COLUMN *p)
 
   print_clump (p, chars, clump_buff);
 
-  for (;;)
+  while (true)
     {
       c = getc (p->fp);
 
@@ -2783,7 +2785,7 @@ Mandatory arguments to long options are mandatory for short options too.\n\
   -COLUMN, --columns=COLUMN\n\
                     output COLUMN columns and print columns down,\n\
                     unless -a is used. Balance number of lines in the\n\
-                    columns on each page.\n\
+                    columns on each page\n\
 "), stdout);
       fputs (_("\
   -a, --across      print columns across rather than down, used together\n\
