@@ -1,5 +1,5 @@
 /* uniq -- remove duplicate lines from a sorted file
-   Copyright (C) 86, 91, 1995-2009 Free Software Foundation, Inc.
+   Copyright (C) 1986, 1991, 1995-2011 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include "argmatch.h"
 #include "linebuffer.h"
 #include "error.h"
+#include "fadvise.h"
 #include "hard-locale.h"
 #include "posixver.h"
 #include "quote.h"
@@ -152,7 +153,7 @@ Mandatory arguments to long options are mandatory for short options too.\n\
      fputs (_("\
   -D, --all-repeated[=delimit-method]  print all duplicate lines\n\
                         delimit-method={none(default),prepend,separate}\n\
-                        Delimiting is done with blank lines.\n\
+                        Delimiting is done with blank lines\n\
   -f, --skip-fields=N   avoid comparing the first N fields\n\
   -i, --ignore-case     ignore differences in case when comparing\n\
   -s, --skip-chars=N    avoid comparing the first N characters\n\
@@ -286,6 +287,8 @@ check_file (const char *infile, const char *outfile, char delimiter)
   if (! (STREQ (outfile, "-") || freopen (outfile, "w", stdout)))
     error (EXIT_FAILURE, errno, "%s", outfile);
 
+  fadvise (stdin, FADVISE_SEQUENTIAL);
+
   thisline = &lb1;
   prevline = &lb2;
 
@@ -301,8 +304,8 @@ check_file (const char *infile, const char *outfile, char delimiter)
 
   if (output_unique && output_first_repeated && countmode == count_none)
     {
-      char *prevfield IF_LINT (= NULL);
-      size_t prevlen IF_LINT (= 0);
+      char *prevfield IF_LINT ( = NULL);
+      size_t prevlen IF_LINT ( = 0);
 
       while (!feof (stdin))
         {
@@ -434,7 +437,7 @@ main (int argc, char **argv)
   countmode = count_none;
   delimit_groups = DM_NONE;
 
-  for (;;)
+  while (true)
     {
       /* Parse an operand with leading "+" as a file after "--" was
          seen; or if pedantic and a file was seen; or if not
